/*
** Class:  LotROLinux.GameSelectWindow
** Author: Alan Jackson
** Date:   17th March 2008
**
** Window shown when there are multiple game accounts
** for the game Lord of the Rings Online
**
** Based on a script by SNy <SNy@bmx-chemnitz.de>
**
** (C) 2007-2008 AJackson <ajackson@bcs.org.uk>
**
** This file is part of LotROLinux.
**
** LotROLinux is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 3 of the License, or
** (at your option) any later version.
**
** LotROLinux is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with LotROLinux.  If not, see <http://www.gnu.org/licenses/>.
*/
using System;
using Glade;
using Gtk;
using System.Collections.Generic; 

namespace LotROLinux
{
	public class GameSelectWindow
	{
		[Widget]
		private Dialog winGameSelect;

		[Widget]
        private ComboBox cboGame;

		private List<Game> gameList;

		public GameSelectWindow(List<Game> gameList)
		{
			Glade.XML gxml = new Glade.XML (null, "GameSelectWindow.glade", "winGameSelect", null);
			gxml.Autoconnect (this);

			cboGame.Clear();
	        CellRendererText cell = new CellRendererText();
	        cboGame.PackStart(cell, false);
	        cboGame.AddAttribute(cell, "text", 0);
	        ListStore store = new ListStore(typeof (string));
	        cboGame.Model = store;

			this.gameList = gameList;

			foreach (Game game in this.gameList)
			{
				cboGame.AppendText(game.GetDescription());
			}

			cboGame.Active = 0;;
		}

		public ResponseType Run()
		{
			return (ResponseType)winGameSelect.Run();
		}

		public void Destroy()
		{
			winGameSelect.Destroy();
		}

		public string GetGameName()
		{
			return gameList[cboGame.Active].GetName();
		}
	}
}
