/*
** Class:  LotROLinux.JoinWorldQueue
** Author: Alan Jackson
** Date:   6th June 2007
**
** Class to join the server login queue using the details
** supplied for the game Lord of the Rings Online
**
** Based on a script by SNy <SNy@bmx-chemnitz.de>
**
** (C) 2007 AJackson <ajackson@bcs.org.uk>
**
** This file is part of LotROLinux.
**
** LotROLinux is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** LotROLinux is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with LotROLinux; if not, write to the Free Software
** Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
using System;
using System.IO;
using System.Web;
using System.Net;
using System.Xml;
using System.Text;

namespace LotROLinux
{
	public class JoinWorldQueue
	{
		private const string keyConfigFile = "WorldQueue.config";
		private const string keyHResult = "HResult";
		private const string keySuccess = "0x00000000";
		private const string keyQueueNumber = "QueueNumber";
		private const string keyServing = "NowServingNumber";

		private string encTicket;
		private string encQueue;
		private string argComplete;
		private string valQueueNumber;
		private string valServing;
		private bool flagJoinSuccess;

		public JoinWorldQueue(string argTemplate, string account, string ticket,
			string queue, string url, string homeDir, string configDir)
		{
			encTicket = HttpUtility.UrlEncode(ticket);
			encQueue = HttpUtility.UrlEncode(queue);

			argComplete = String.Format(argTemplate, account,
				encTicket, encQueue);

			try
			{
				WebRequest loginRequest = WebRequest.Create (url);
			
				loginRequest.Method = "POST";
				loginRequest.ContentType = "application/x-www-form-urlencoded";
			
				loginRequest.ContentLength = argComplete.Length;

				Stream bodyStream = loginRequest.GetRequestStream();
				StreamWriter bodyStreamWrite = new StreamWriter (bodyStream);

				bodyStreamWrite.Write (argComplete);

				bodyStreamWrite.Flush();

				bodyStreamWrite.Close();
			
				bodyStream.Close ();
				
				WebResponse loginResponse = loginRequest.GetResponse ();

				XmlDocument xDoc = new XmlDocument();
		
				xDoc.Load(loginResponse.GetResponseStream ());

				xDoc.Save(String.Format("{0}{1}{2}", homeDir, configDir, keyConfigFile));
				
				loginResponse.Close();

				if (xDoc.GetElementsByTagName(keyHResult)[0].InnerText == keySuccess)
				{
					flagJoinSuccess = true;

					valQueueNumber = xDoc.GetElementsByTagName(keyQueueNumber)[0].InnerText;
					valServing = xDoc.GetElementsByTagName(keyServing)[0].InnerText;
				} else {
					flagJoinSuccess = false;
				}
			}
			catch
			{
				flagJoinSuccess = false;
			}
		}
		
		public bool IsJoinSuccess
		{
			get { return flagJoinSuccess; }
		}

		public string QueueNumber
		{
			get { return valQueueNumber; }
		}

		public string NowServing
		{
			get { return valServing; }
		}
	}
}
