/*
** Class:  LotROLinux.StartGame
** Author: Alan Jackson
** Date:   6th June 2007
**
** Class to start the game Lord of the Rings Online
**
** Based on a script by SNy <SNy@bmx-chemnitz.de>
**
** (C) 2007-2008 AJackson <ajackson@bcs.org.uk>
**
** This file is part of LotROLinux.
**
** LotROLinux is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 3 of the License, or
** (at your option) any later version.
**
** LotROLinux is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with LotROLinux.  If not, see <http://www.gnu.org/licenses/>.
*/
using Gtk;
using System;
using System.IO;
using System.Diagnostics;

namespace LotROLinux
{
	public class StartGame
	{
		private const string strWineDebug = "WINEDEBUG";
		private const string strWinePrefix = "WINEPREFIX";
		private const string fileLog = "run.log";
		private const string keyAppWine = "Wine";
		private const string keyAppCXGames = "CXGames";
		private const string keyAppCXOffice = "CXOffice";
	
		private string gameParams;
		private string logFile;
		private Process game;
		private bool wineLog;
	
		public StartGame(string appName, string argTemplate,
			string account, string server, string ticket,
			string chatServer, string language, string runDir,
			string wineProgram, string wineParams,
			string wineDebug, string winePrefix, 
			string homeDir, bool wineLog, bool hiResEnabled,
			string wineApp, DetermineOS osType)
		{
			FileInfo tempFile;

			logFile = String.Format("{0}{1}/{2}", homeDir, osType.AppDir, fileLog);

			gameParams = String.Format(argTemplate, account,
				server, ticket, chatServer, language);

			if (!hiResEnabled)
			{
				gameParams = String.Format("{0} --HighResOutOfDate", gameParams);
			}
			
			game = new Process();

			switch (wineApp)
			{
				case keyAppWine:
					game.StartInfo.FileName = wineProgram;
					break;
				case keyAppCXGames:
					if (osType.MacPathCX == "")
					{
						tempFile = new FileInfo(String.Format("{0}{1}{2}", osType.GlobalDir, osType.DirectoryCXG,
							wineProgram));

						if (tempFile.Exists)
						{
							game.StartInfo.FileName = String.Format("{0}{1}{2}", osType.GlobalDir, osType.DirectoryCXG,
								wineProgram);
						} else {
							tempFile = new FileInfo(String.Format("{0}{1}{2}", homeDir, osType.DirectoryCXG, wineProgram));
							if (tempFile.Exists)
							{
								game.StartInfo.FileName = String.Format("{0}{1}{2}", homeDir, osType.DirectoryCXG,
									wineProgram);
							} else {
								game.StartInfo.FileName = wineProgram;
							}
						}
					} else {
						game.StartInfo.FileName = String.Format("{0}{1}", osType.MacPathCX, wineProgram);
					}
					break;
				case keyAppCXOffice:
					if (osType.MacPathCX == "")
					{
						tempFile = new FileInfo(String.Format("{0}{1}{2}", osType.GlobalDir, osType.DirectoryCXO,
							wineProgram));

						if (tempFile.Exists)
						{
							game.StartInfo.FileName = String.Format("{0}{1}{2}", osType.GlobalDir, osType.DirectoryCXO,
								wineProgram);
						} else {
							tempFile = new FileInfo(String.Format("{0}{1}{2}", homeDir, osType.DirectoryCXO, wineProgram));
							if (tempFile.Exists)
							{
								game.StartInfo.FileName = String.Format("{0}{1}{2}", homeDir, osType.DirectoryCXO,
									wineProgram);
							} else {
								game.StartInfo.FileName = wineProgram;
							}
						}
					} else {
						game.StartInfo.FileName = String.Format("{0}{1}", osType.MacPathCX, wineProgram);
					}
					break;
			}

			game.StartInfo.RedirectStandardError = true;
			
			if (wineDebug != "")
			{
				game.StartInfo.EnvironmentVariables.Add
					(strWineDebug, wineDebug);
			}
			
			if (winePrefix != "")
			{
				if (wineApp == "Wine")
				{
					game.StartInfo.EnvironmentVariables.Add
						(strWinePrefix, winePrefix);
				}
			}
			
			if (wineApp == "Wine")
			{
				game.StartInfo.WorkingDirectory = runDir;

				game.StartInfo.Arguments = String.Format("{0} {1} {2}",
					wineParams, appName, gameParams);
			} else {
				game.StartInfo.Arguments = String.Format("--bottle \"{0}\" --workdir \"{1}\" -- {2} {3}",
					winePrefix, runDir, appName, gameParams);
			}

			game.StartInfo.UseShellExecute = false;

			this.wineLog = wineLog;
		}

		public void Run()
		{
			StreamWriter logWriter;
			string temp;

			game.Start();

			if (wineLog)
			{
				logWriter = new StreamWriter(logFile);

				while (!game.HasExited) {
					temp = game.StandardError.ReadLine();
					if ((temp != null) && (temp.Length > 0)) {
						logWriter.WriteLine(temp);
					}
				}

				logWriter.Close();
			}
		}


	}
}
