/*
** Class:  LotROLinux.WorldQueueConfig
** Author: Alan Jackson
** Date:   6th June 2007
**
** Class to fetch the world queue details using the supplied 
** url for the game Lord of the Rings Online
**
** Based on a script by SNy <SNy@bmx-chemnitz.de>
**
** (C) 2007-2008 AJackson <ajackson@bcs.org.uk>
**
** This file is part of LotROLinux.
**
** LotROLinux is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 3 of the License, or
** (at your option) any later version.
**
** LotROLinux is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with LotROLinux.  If not, see <http://www.gnu.org/licenses/>.
*/
using System;
using System.IO;
using System.Net;
using System.Xml;
using System.Collections;

namespace LotROLinux
{
	
	
	public class WorldQueueConfig
	{
		private const string keyConfigFile = "launcher.config";
		private const string keyComment = "#comment";
		private const string keyFalse = "false";
		private const string attribKeyName = "key";
		private const string keyGameClientFilename = "GameClient.Filename";
		private const string keyGameClientArgTemplate = "GameClient.ArgTemplate";
		private const string keyNewsFeedURL = "URL.NewsFeed";
		private const string keyAlertStyleSheetURL = "URL.AlertsStyleSheet";
		private const string keyNewsStyleSheetURL = "URL.NewsStyleSheet";
		private const string keyWorldQueueURL = "WorldQueue.LoginQueue.URL";
		private const string keyWorldQueueParam = "WorldQueue.TakeANumber.Parameters";
		private const string keyDateTime = "LauncherConfig.DateTime";
		private const string keyAppSettings = "appSettings";
		private const string keyPatchProductCode = "Patching.ProductCode";

		private string valGameClientFilename;
		private string valGameClientArgTemplate;
		private string valNewsFeedURL;
		private string valNewsStyleSheetURL;
		private string valAlertStyleSheetURL;
		private string valWorldQueueURL;
		private string valWorldQueueParam;
		private string valDateTime;
		private string valPatchProductCode;
		private bool flagLoadSuccess;
		
		public WorldQueueConfig(string valConfigServer, string homeDir, string configDir)
		{
			try
			{
				WebRequest confRequest = WebRequest.Create (valConfigServer);

				confRequest.Timeout = 5000;
			
				WebResponse confResponse = confRequest.GetResponse ();

				XmlDocument xDoc = new XmlDocument();
		
				xDoc.Load(confResponse.GetResponseStream ());

				xDoc.Save(String.Format("{0}{1}{2}", homeDir, configDir, keyConfigFile));

				XmlNodeList serverConfig = xDoc.GetElementsByTagName(keyAppSettings)[0].ChildNodes;
				
				foreach (XmlNode appSetting in serverConfig)
				{
					if (appSetting.Name.ToString() != keyComment)
					{
						string tempKey = "";

						foreach (XmlNode setAttrib in appSetting.Attributes)
						{
							if (setAttrib.Name.ToString() == attribKeyName)
							{
								tempKey = setAttrib.InnerText;
							} else {
								switch (tempKey)
								{
									case keyGameClientFilename:
										valGameClientFilename = setAttrib.InnerText;
										break;
									case keyGameClientArgTemplate:
										valGameClientArgTemplate = setAttrib.InnerText;
										break;
									case keyNewsStyleSheetURL:
										valNewsStyleSheetURL = setAttrib.InnerText;
										break;
									case keyAlertStyleSheetURL:
										valAlertStyleSheetURL = setAttrib.InnerText;
										break;
									case keyNewsFeedURL:
										valNewsFeedURL = setAttrib.InnerText;
										break;
									case keyWorldQueueURL:
										valWorldQueueURL = setAttrib.InnerText;
										break;
									case keyWorldQueueParam:
										valWorldQueueParam = setAttrib.InnerText;
										break;
									case keyDateTime:
										valDateTime = setAttrib.InnerText;
										break;
									case keyPatchProductCode:
										valPatchProductCode = setAttrib.InnerText;
										break;
								}
							}
						}
					}
				}
				flagLoadSuccess = true;
			}
			catch
			{
				flagLoadSuccess = false;
			}
		}
	
		public string GetGameFilename()
		{
			return valGameClientFilename;
		}
		
		public string GetGameArgTemplate()
		{
			return valGameClientArgTemplate;
		}
		
		public string GetWorldQueueURL()
		{
			return valWorldQueueURL;
		}
		
		public string GetWorldQueueParam()
		{
			return valWorldQueueParam;
		}
		
		public string GetNewsFeedURL()
		{
			return valNewsFeedURL;
		}

		public string GetNewsStyleSheetURL()
		{
			return valNewsStyleSheetURL;
		}

		public string GetAlertStyleSheetURL()
		{
			return valAlertStyleSheetURL;
		}

		public string GetDateTime()
		{
			return valDateTime;
		}

		public string GetPatchProductCode()
		{
			return valPatchProductCode;
		}

		public bool IsLoadSuccess()
		{
			return flagLoadSuccess;
		}
	}
}
